"""Logger for connectome python projects."""
import logging

def getLogger(module_name='connectome_module'):
    """Get logger with specified logger name."""
    fmt = '%(asctime)s.%(msecs)03d | %(name)s | [%(levelname)s]: %(message)s'
    datefmt = '%d-%m-%Y %H:%M:%S'
    logging.basicConfig(level=logging.DEBUG, format=fmt, datefmt=datefmt)
    logger = logging.getLogger(module_name)
    return logger



#!/usr/bin/env python3

import distutils.cmd
import distutils.log
import os
import subprocess

from setuptools import find_packages, setup

install_requires = []

CONFIG = {
    'name': 'ourLittleLogger',
    'version': '0.1.2',
    'url': 'https://gitlab.com/benzolium/python-logger',
    'description': 'ourLittleLogger is used for logging unification.',
    'author': 'connectome.ai',
    'test_suite': 'ourLittleLogger',
    'packages': find_packages(),
    'install_requires': install_requires
}

setup(**CONFIG)
